@@ -17,7 +17,7 @@ def cdn_media():
     css = {
         "all": (
             "//cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/"
-            "5.1.2/css/tempusdominus-bootstrap-4.min.css",
+            "5.39.0/css/tempusdominus-bootstrap-4.min.css",
         )
     }
 
@@ -33,7 +33,7 @@ def cdn_media():
         ),
         (
             "//cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/"
-            "5.1.2/js/tempusdominus-bootstrap-4.min.js"
+            "5.39.0/js/tempusdominus-bootstrap-4.min.js"
         ),
     )
 
@@ -160,11 +160,17 @@ class TempusDominusMixin:
         """
         if isinstance(value, str):
             if isinstance(self, DatePicker):
-                formats = [self.format] or get_format("DATE_INPUT_FORMATS")
+                formats = [self.format] if self.format else get_format(
+                    "DATE_INPUT_FORMATS"
+                )
             elif isinstance(self, TimePicker):
-                formats = [self.format] or get_format("TIME_INPUT_FORMATS")
+                formats = [self.format] if self.format else get_format(
+                    "TIME_INPUT_FORMATS"
+                )
             else:
-                formats = get_format("DATETIME_INPUT_FORMATS")
+                formats = [self.format] if self.format else get_format(
+                    "DATETIME_INPUT_FORMATS"
+                )
             for fmt in formats:
                 try:
                     value = datetime.strptime(value, fmt)
